.. image:: https://travis-ci.org/michaelrice/gotland.svg
    :target: https://travis-ci.org/michaelrice/gotland
    :alt: Build Status

gotland
=======

Python bindings for the `rabbitmq management http api <https://www.rabbitmq.com/management.html>`_. The name comes from 
the `Swedish variety <http://en.wikipedia.org/wiki/Gotland_rabbit>`_ of rabbit.


License
=======
gotland is released under the terms of the Apache-2.0 licenses.

Examples
========
For the most comprehensive list of how the library works please see the tests

Contributing
============
Pull requests are always welcome and greatly appreciated. When sending them please follow the fork and branch workflow, 
and open your pull request against the devel branch. Please include in a test where applicable using 
`vcrpy <https://pypi.python.org/pypi/vcrpy>`_. You should include a test that shows the failure and a fix if possible.


Installing
==========

    pip install gotland